@@ -498,25 +498,25 @@ RECOMMENDATION_TEMPLATE = """\
     <head></head>
     <body>
         <p>Hello, {name}.</p>
-        
+
         <p>
-        Attached are your recommended targets for tonight.
+        Attached are your recommended targets for {facility} tonight.
         This email is for convenience purposes. Log in at
-        <a href="https://refitt.org">refitt.org</a> to adjust your notification
+        <a href="http://refitt.org">refitt.org</a> to adjust your notification
         preferences. Below is a preview of the first few targets.
         </p>
         <br>
-        
+
         {table}
-        
+
         <br>
         <p><em>Thanks!</em><br>
         REFITT Team<p>
-        
+
         <p>--<br>
         This email was automatically generated by the REFITT system.<br>
         This information is current as of {date}.<br>
-        Log in at <a href="https://refitt.org">refitt.org</a> for details.
+        Log in at <a href="http://refitt.org">refitt.org</a> for details.
         </p>
         <br>
     </body>
@@ -529,9 +529,9 @@ class RecommendationMail(MailTemplate):
 
     required = 1
 
-    def __init__(self, name: str, *args, **kwargs) -> None:
+    def __init__(self, facility: str, name: str, *args, **kwargs) -> None:
         """
-        Initialize template with a person's `name`.
+        Initialize template with a facility `facility` and a person's `name`.
         A single attachment is required to be a CSV file.
         """
 
@@ -568,8 +568,8 @@ class RecommendationMail(MailTemplate):
 
         # format html message
         date = time.strftime('%a, %d %b %Y %T UTC')
-        self.html = RECOMMENDATION_TEMPLATE.format(name=name, table=table, date=date)
-        self.subject = f'REFITT Recommendations ({date})'
+        self.html = RECOMMENDATION_TEMPLATE.format(facility=facility, name=name, table=table, date=date)
+        self.subject = f'REFITT Recommendations for {facility} ({date})'
 
 
 # named templates and their classes
