@@ -52,7 +52,7 @@ class TestClient:
             'key': '78h6IuhW30Re7I-C',
             'secret': '7ccb08b171f4a28e6b5f2af5597153873d7cd90a972f2bee7b8ac82c43e0e4e9',
             'valid': True,
-            'created': '2020-10-23 17:45:01' + ('' if config.backend == 'sqlite' else '-04:00'),
+            'created': '2020-10-23 17:45:01' + ('' if config.provider == 'sqlite' else '-04:00'),
             'user': {
                 'id': 2,
                 'first_name': 'Jason',
